@echo off
::
:: GetSQL.bat Backup SQL database via script with basic error handling
:: This .bat file can be called from an rbclient pre file when the SQL plugin won't work
:: or the backup is too big and must then be split.
:: MDR 1/15/2014 - revised, adapted from custom script
:: MDR 1/7/2020 - silent mode on gsplit

::
:: Setup Constants
::

:: 1. Specify the name of the logical database as found in SQL
SET DATABASENAME=DERMATOLOGY CENTER IN THE BERKSHIRES PC
ECHO Databasename = %DATABASENAME%

:: 2. Specify root folder under which the database backup will be stored
SET DATABASESTOREROOT=C:\LytecData\GsplitSQLBackup\MyDatabase
ECHO DatabaseStoreRoot = %DATABASESTOREROOT%

:: 3. Specify the SQL Server connection string node\instance or .\instance
SET DATABASECONNECTSTRING=.\Lytec_SQL
ECHO DatabaseConnectString = %DATABASECONNECTSTRING%

:: ------------- DO NOT MAKE CHANGES BELOW THIS LINE --------------
 
SET BACKUPDESCRIPTION=Backup MS-SQL Database %DATABASENAME%
ECHO BackupDescription = %BACKUPDESCRIPTION%

SET DATABASESTORE=%DATABASESTOREROOT%\%DATABASENAME%
ECHO DatabaseStore = %DATABASESTORE%

SET DATABASEPATH=%DATABASESTORE%\%DATABASENAME%
ECHO DatabasePath = %DATABASEPATH%.bak

::
:: Write out sentinel file which if present at end of script means error detected or abort
::

MKDIR "%DATABASESTORE%"
ECHO %BACKUPDESCRIPTION% Error Detected > "%DATABASESTORE%\##CUSTOMERROR##.txt"

::
:: Create the SQL Backup command file
::

CD /D "%DATABASESTOREROOT%"
DEL /Q "%DATABASENAME%.err"
DEL /Q "%DATABASENAME%.cmd"
ECHO BACKUP DATABASE [%DATABASENAME%] TO DISK = '%DATABASEPATH%.bak' WITH INIT, NO_COMPRESSION; > "%DATABASENAME%.cmd"
ECHO GO >> "%DATABASENAME%.cmd"

::
:: Delete old database if present
::

DEL /Q "%DATABASEPATH%.bak"

::
:: Lets do the SQL Backup here
::

SQLCMD -S %DATABASECONNECTSTRING% -i "%DATABASENAME%.cmd" > "%DATABASENAME%.err"

::
:: If there was no error, then lets get rid of sentinel error file
::

FINDSTR /i "abnormally" "%DATABASENAME%.err"
ECHO ErrorLevel = %ERRORLEVEL%
IF ERRORLEVEL 0 IF NOT ERRORLEVEL 1 GOTO DONE
DEL /Q "%DATABASESTORE%\##CUSTOMERROR##.txt"

::
:: That should be good. Either complete SQL backup file will exist or error sentinel file
:: ##CUSTOMERROR##.txt will exist where the backup database should be
::

:DONE
